Package: abd
Type: Package
Title: The Analysis of Biological Data
Version: 0.2-8
Date: 2015-07-02
Author: Kevin M. Middleton <middletonk@missouri.edu>, Randall Pruim
    <rpruim@calvin.edu>
Maintainer: Kevin M. Middleton <middletonk@missouri.edu>
Depends: R (>= 3.0), nlme, lattice, grid, mosaic
Suggests: boot, car, ggplot2, plyr, HH, ICC, vcd, Hmisc
Description: The abd package contains data sets and sample code for The
    Analysis of Biological Data by Michael Whitlock and Dolph Schluter (2009;
    Roberts & Company Publishers).
License: GPL-2
LazyLoad: yes
LazyData: yes
Encoding: UTF-8
Collate: 'abdData.R' 'histochart.R' 'datasets.R' 'themes.R'
NeedsCompilation: no
Packaged: 2015-07-03 01:35:03 UTC; kmm
Repository: CRAN
Date/Publication: 2015-07-03 05:44:45
Built: R 4.6.0; ; 2026-04-30 23:33:59 UTC; unix
