# Generated by roxygen2 (4.1.1): do not edit by hand

export(abdData)
export(col.abd)
export(histochart)
export(theme.abd)
import(grid)
import(lattice)
import(mosaic)
import(nlme)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,gray)
