# Figure 2.5-1
xyplot(son.attract ~ father.ornament, data=Guppies,
	xlab="Father's ornamentation",
	ylab="Son's attractiveness")

# Figure 2.5-2
xyplot(pelts ~ year, Lynx,
	type='b',
	ylab="Lynx fur returns",
	xlab="Year")


